@@ -1,10 +1,13 @@
 import inspect as _inspect
 from collections.abc import Callable, Awaitable
-from typing import Literal, Union
+from typing import Literal
 
 from bolinette import blnt, core, web, BolinetteExtension
 from bolinette.blnt.commands import Command as _Command, Argument as _Argument
-from bolinette.utils import InitProxy as _InitProxy
+
+
+def injected(func):
+    return blnt.InjectionProxy(func)
 
 
 def model(model_name: str, *,
@@ -53,16 +56,16 @@ def seeder(func):
 
 
 def service(service_name: str, *, model_name: str = None):
-    def decorator(service_cls: type[Union['core.Service', 'core.SimpleService']]):
+    def decorator(service_cls: type[core.Service | core.SimpleService]):
         service_cls.__blnt__ = core.ServiceMetadata(service_name, model_name or service_name)
         blnt.cache.services[service_name] = service_cls
         return service_cls
     return decorator
 
 
-def controller(controller_name: str, path: str = None, *,
+def controller(controller_name: str, path: str | None = None, *,
                namespace: str = '/api', use_service: bool = True,
-               service_name: str = None, middlewares: Union[str, list[str]] = None):
+               service_name: str = None, middlewares: str | list[str] | None = None):
     if path is None:
         path = f'/{controller_name}'
     if service_name is None:
@@ -81,51 +84,53 @@ def controller(controller_name: str, path: str = None, *,
 
 
 def route(path: str, *, method: web.HttpMethod, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
-          middlewares: Union[str, list[str]] = None):
+          middlewares: str | list[str] | None = None):
     if middlewares is None:
         middlewares = []
     if isinstance(middlewares, str):
         middlewares = [middlewares]
 
     def decorator(route_function: Callable):
-        if not isinstance(route_function, _InitProxy) and not _inspect.iscoroutinefunction(route_function):
+        if (not isinstance(route_function, blnt.InstantiableAttribute)
+                and not _inspect.iscoroutinefunction(route_function)):
             raise ValueError(f'Route "{route_function.__name__}" must be an async function')
         if expects is not None and not isinstance(expects, web.Expects):
             raise ValueError(f'Route "{route_function.__name__}": expects argument must be of type web.Expects')
         if returns is not None and not isinstance(returns, web.Returns):
             raise ValueError(f'Route "{route_function.__name__}": expects argument must be of type web.Returns')
         inner_route = None
-        if isinstance(route_function, _InitProxy):
+        if isinstance(route_function, blnt.InstantiableAttribute):
             inner_route = route_function
         docstring = route_function.__doc__
-        return _InitProxy(web.ControllerRoute, func=route_function, path=path, method=method,
-                          docstring=docstring, expects=expects, returns=returns, inner_route=inner_route,
-                          middlewares=middlewares)
+        return blnt.InstantiableAttribute(web.ControllerRoute, dict(
+            func=route_function, path=path, method=method, docstring=docstring, expects=expects,
+            returns=returns, inner_route=inner_route, middlewares=middlewares
+        ))
     return decorator
 
 
 def get(path: str, *, returns: 'web.Returns' = None,
-        middlewares: Union[str, list[str]] = None):
+        middlewares: str | list[str] | None = None):
     return route(path, method=web.HttpMethod.GET, expects=None, returns=returns, middlewares=middlewares)
 
 
 def post(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
-         middlewares: Union[str, list[str]] = None):
+         middlewares: str | list[str] | None = None):
     return route(path, method=web.HttpMethod.POST, expects=expects, returns=returns, middlewares=middlewares)
 
 
 def put(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
-        middlewares: Union[str, list[str]] = None):
+        middlewares: str | list[str] | None = None):
     return route(path, method=web.HttpMethod.PUT, expects=expects, returns=returns, middlewares=middlewares)
 
 
 def patch(path: str, *, expects: 'web.Expects' = None, returns: 'web.Returns' = None,
-          middlewares: Union[str, list[str]] = None):
+          middlewares: str | list[str] | None = None):
     return route(path, method=web.HttpMethod.PATCH, expects=expects, returns=returns, middlewares=middlewares)
 
 
 def delete(path: str, *, returns: 'web.Returns' = None,
-           middlewares: Union[str, list[str]] = None):
+           middlewares: str | list[str] | None = None):
     return route(path, method=web.HttpMethod.DELETE, expects=None, returns=returns, middlewares=middlewares)
 
 
@@ -184,7 +189,7 @@ class _CommandDecorator:
             if arg_type not in ['argument', 'option', 'flag', 'count']:
                 raise ValueError(f'Command {cmd.name}: {arg_type} is not a valid argument type')
             cmd.args = [_Argument(arg_type, name, flag=flag, summary=summary, value_type=value_type,
-                                         default=default, choices=choices)] + cmd.args
+                                  default=default, choices=choices)] + cmd.args
             return cmd
         return decorator
 
