@@ -4,15 +4,16 @@ from asyncio.events import AbstractEventLoop
 from aiohttp import test_utils
 
 import bolinette
+from bolinette import abc
 from bolinette.testing import Mock
 from bolinette.utils.serializing import serialize
 
 
-class BolitestClient:
+class BolitestClient(abc.WithContext):
     def __init__(self, blnt_app: 'bolinette.Bolinette', loop: AbstractEventLoop):
+        super().__init__(blnt_app.context)
         server = test_utils.TestServer(blnt_app.app, loop=loop)
         self.client = test_utils.TestClient(server, loop=loop)
-        self.context = blnt_app.context
         self.mock = Mock(blnt_app.context)
         self.cookies = {}
 
@@ -25,6 +26,12 @@ class BolitestClient:
     def __await__(self):
         return self.__aenter__().__await__()
 
+    def try_parse(self, response):
+        try:
+            return json.loads(response)
+        except json.JSONDecodeError:
+            return response
+
     def payload(self, **payload):
         if 'csrf_access_token' in self.cookies:
             payload['headers'] = {}
@@ -44,7 +51,7 @@ class BolitestClient:
                                      headers={'Content-Type': 'application/json'})
         self.parse_cookies(res.headers)
         text = await res.text()
-        return json.loads(text)
+        return self.try_parse(text)
 
     async def put(self, path: str, data: dict = None, *, prefix='/api') -> dict:
         if data is None:
@@ -53,7 +60,7 @@ class BolitestClient:
                                     headers={'Content-Type': 'application/json'})
         self.parse_cookies(res.headers)
         text = await res.text()
-        return json.loads(text)
+        return self.try_parse(text)
 
     async def patch(self, path: str, data: dict = None, *, prefix='/api') -> dict:
         if data is None:
@@ -62,14 +69,14 @@ class BolitestClient:
                                       headers={'Content-Type': 'application/json'})
         self.parse_cookies(res.headers)
         text = await res.text()
-        return json.loads(text)
+        return self.try_parse(text)
 
     async def get(self, path: str, *, prefix='/api') -> dict:
         res = await self.client.get(f'{prefix}{path}')
         text = await res.text()
-        return json.loads(text)
+        return self.try_parse(text)
 
     async def delete(self, path: str, *, prefix='/api') -> dict:
         res = await self.client.delete(f'{prefix}{path}')
         text = await res.text()
-        return json.loads(text)
+        return self.try_parse(text)
